# -*- coding: utf-8 -*-
# Generated by Django 2.1.5 on 2019-01-22 04:12
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangocms_modules', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='category',
            options={'verbose_name': 'Category', 'verbose_name_plural': 'Categories'},
        ),
        migrations.AlterField(
            model_name='category',
            name='name',
            field=models.CharField(max_length=120, unique=True, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='moduleplugin',
            name='module_category',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='djangocms_modules.Category', verbose_name='Category'),
        ),
        migrations.AlterField(
            model_name='moduleplugin',
            name='module_name',
            field=models.CharField(max_length=120, verbose_name='Name'),
        ),
    ]
